========
grafyaml
========

Grafyaml takes simple descriptions of Grafana dashboards in YAML format, and
uses them to configure Grafana.

* Free software: Apache license
* Documentation: http://docs.openstack.org/infra/grafyaml/
* Source: http://git.openstack.org/cgit/openstack-infra/grafyaml
* Bugs: https://storyboard.openstack.org/#!/project/818

Features
--------

* TODO
